<?php
/** Southern Sami (Åarjelsaemien)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Andrijko Z.
 * @author Bïerne
 * @author M.M.S.
 * @author Urhixidur
 */

$messages = array(
# User preference toggles
'tog-showtoolbar' => 'Dïrregesïeve vuesehth (JavaScript)',
'tog-fancysig'    => 'Saajpe singnatuvreh (namhtah jïjtsistie lïenghke)',

'underline-always' => 'Iktesth',
'underline-never'  => 'Aaltere',

# Dates
'sunday'        => 'Aejlege',
'monday'        => 'Måanta',
'tuesday'       => 'Däjsta',
'wednesday'     => 'Gaske-våhkoe',
'thursday'      => 'Dåarsta',
'friday'        => 'Bearjedh',
'saturday'      => 'Laavadahke',
'sun'           => 'Aej',
'mon'           => 'Måa',
'tue'           => 'Däj',
'wed'           => 'Gas',
'thu'           => 'Dåa',
'fri'           => 'Bea',
'sat'           => 'Laa',
'january'       => 'tsiengele',
'february'      => 'goevte',
'march'         => 'njoktje',
'april'         => 'Voerhtje',
'may_long'      => 'Suehpede',
'june'          => 'Ruffie',
'july'          => 'Snjaltje',
'august'        => 'Mïetske',
'september'     => 'Gaekere',
'october'       => 'Golke',
'november'      => 'Rahka',
'december'      => 'Goeve',
'january-gen'   => 'Tsiengele',
'february-gen'  => 'Goevte',
'march-gen'     => 'Njoktje',
'april-gen'     => 'Voerhtje',
'may-gen'       => 'Suehpede',
'june-gen'      => 'Ruffie',
'july-gen'      => 'Snjaltje',
'august-gen'    => 'Mïetske',
'september-gen' => 'Gaekere',
'october-gen'   => 'Golke',
'november-gen'  => 'Rahka',
'december-gen'  => 'Goeve',
'jan'           => 'Tsi',
'feb'           => 'Goe',
'mar'           => 'Njo',
'apr'           => 'Voe',
'may'           => 'Sue',
'jun'           => 'Ruf',
'jul'           => 'Snj',
'aug'           => 'Mïe',
'sep'           => 'Gae',
'oct'           => 'Gol',
'nov'           => 'Rah',
'dec'           => 'Goe',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Kategorije|Kategorijeh}}',
'category_header'        => 'Bielie sïjse kategorije "$1"',
'subcategories'          => 'Subkategorijeh',
'category-media-header'  => 'Guvvie sïjse karegorije "$1"',
'category-empty'         => "''Dïhte kategorije sisvege ijje bielieh jallh baalkah.''",
'listingcontinuesabbrev' => 'jåar.',

'about'         => 'Bïjre',
'article'       => 'Sisvege bielie',
'newwindow'     => '(geehpehtidh sïjse orre klaase)',
'cancel'        => 'Orrijidh',
'moredotdotdot' => 'Jienebe...',
'mypage'        => 'Mov bielie',
'mytalk'        => 'Mov dïjveldidh',
'anontalk'      => 'Dïjveldidh ihke dïhte IP',
'navigation'    => 'Navigasjovne',
'and'           => '&#32;jih',

# Cologne Blue skin
'qbfind'         => 'Gaavnedh',
'qbedit'         => 'Värrhtoedimmie',
'qbpageoptions'  => 'Dïhte bielie',
'qbmyoptions'    => 'Mov bielieh',
'qbspecialpages' => 'Joekoelaakan bielieh',
'faq'            => 'FAQ',
'faqpage'        => 'Project:FAQ',

'errorpagetitle'   => 'Båajhtode',
'returnto'         => 'Bååstide gåajkoe $1.',
'tagline'          => '{{SITENAME}}sta',
'help'             => 'Viehkie',
'search'           => 'Ohtsedh',
'searchbutton'     => 'Ohtsedh',
'go'               => 'Vaadtsa',
'searcharticle'    => 'Vaadtsa',
'history'          => 'Histovrije',
'history_short'    => 'Histovrije',
'info_short'       => 'Bïevnesh',
'printableversion' => 'Tjaelije bielie',
'permalink'        => 'Permanente lïenghke',
'print'            => 'Tjaeledh olkese',
'edit'             => 'Sjiehtedh',
'editthispage'     => 'Värrhtoedimmie dïhte bielie',
'delete'           => 'Tjåegkedh',
'protect'          => 'Vaarjelidh',
'protectthispage'  => 'Vaarjelidh dïhte bielie',
'newpage'          => 'Orre bielie',
'talkpage'         => 'Dïjveldidh dïhte bielie',
'talkpagelinktext' => 'Digkiedimmie',
'specialpage'      => 'Joekoelaakan Bielie',
'personaltools'    => 'Persjovne dïrregeh',
'articlepage'      => 'Vuesehte artihkle bielie',
'talk'             => 'Dïjveldeme',
'views'            => 'Vuesehth',
'toolbox'          => 'Dïrregeborhtje',
'userpage'         => 'Vuesehte nuhtjienbielie',
'projectpage'      => 'Vuesehte Wikipedijebielie',
'imagepage'        => 'Vuesehte guvvie bielie',
'templatepage'     => 'Vuesehte maale bielie',
'viewhelppage'     => 'Vuesehte viehkie bielie',
'categorypage'     => 'Vuesehte kategorije bielie',
'viewtalkpage'     => 'Vuesehte dïjveldidh',
'otherlanguages'   => 'jeatjebh gïele',
'redirectedfrom'   => '(Bïjre-dirisjovne raejeste $1)',
'redirectpagesub'  => 'Bïjre-dirisjovne bielie',
'protectedpage'    => 'Vaarjelidh bielie',
'jumpto'           => 'Vaadtsa gåajkoe:',
'jumptonavigation' => 'navigasjovne',
'jumptosearch'     => 'ohtsedh',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}}en bïjre',
'aboutpage'            => 'Project:Bïjre',
'copyrightpage'        => '{{ns:project}}:Bäjjesereaktah',
'currentevents'        => 'Daaletje deahpadimmieh',
'currentevents-url'    => 'Project:Daaletje deahpadimmieh',
'disclaimers'          => 'Friijavuohte vastideamis',
'disclaimerpage'       => 'Project:Bäjjesereaktah',
'edithelp'             => 'Sjiehtedimmie viehkie',
'edithelppage'         => 'Help:Sjiehtedimmie',
'helppage'             => 'Help:Sisvege',
'mainpage'             => 'Aalkoebielie',
'mainpage-description' => 'Aalkoebielie',
'portal'               => 'Meatan portaale',
'portal-url'           => 'Project:Meatan portaale',
'privacy'              => 'Privaate pålisy',
'privacypage'          => 'Project:Privaate pålisy',

'retrievedfrom'       => 'Raejeste "$1" vïedtjeme',
'youhavenewmessages'  => 'Datne åtna $1 ($2).',
'newmessageslink'     => 'orre bïjre',
'newmessagesdifflink' => 'minngemes värrhtoedimmie',
'editsection'         => 'sjïehtedh',
'editold'             => 'värrhtoedimmie',
'editsectionhint'     => 'Sektiovne sjiehtedh: $1',
'toc'                 => 'Sisvege',
'showtoc'             => 'vuesehte',
'hidetoc'             => 'gaptjedh',
'viewdeleted'         => 'Vuesehte $1?',
'site-rss-feed'       => '$1 RSS Feed',
'site-atom-feed'      => '$1 Atom Feed',
'page-rss-feed'       => '"$1" RSS Feed',
'page-atom-feed'      => '"$1" Atom Feed',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Bielie',
'nstab-user'      => 'Nuhtjien bielie',
'nstab-media'     => 'Guvvie',
'nstab-special'   => 'Joekoelaakan',
'nstab-project'   => 'Prosjekte bielie',
'nstab-image'     => 'Baalka',
'nstab-mediawiki' => 'MediaWiki',
'nstab-template'  => 'Maale',
'nstab-help'      => 'Viehke bielie',
'nstab-category'  => 'Kategorije',

# General errors
'error'              => 'Båajhtode',
'databaseerror'      => 'Daatabaase båajhtode',
'readonly'           => 'Daatabaase steegkeldahkesne',
'internalerror'      => 'Sjisjnjie båajhtede',
'internalerror_info' => 'Sjisjnjie båajhtede: $1',
'badtitle'           => 'Gååre nomme',
'badtitletext'       => 'Dïhte bielietiitele lea nov sån ijje luhpede, bielie lea gåaroes, jallh lea bielie gåarhmede lïenghke gåajkoe.',
'viewsource'         => 'Vuesehte tjaalege',
'viewsourcefor'      => 'ihke $1',
'viewsourcetext'     => 'Dov dorje vuesehte jih kåpieerae gaaltjie dejstie dïhte bielie:',

# Login and logout pages
'yourname'                => 'Nuhtjiennomme:',
'yourpassword'            => 'Loevesbaakoe:',
'remembermypassword'      => 'Måjhtije mov loggesïjse nille dïhte daatovre (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'          => 'Dov domäne:',
'login'                   => 'Logge sïjse',
'nav-login-createaccount' => 'Logge sïjse / skaepede nuhtjien',
'loginprompt'             => 'Dov galkedh luhpede cookies ihke logge sïjse nille {{SITENAME}}.',
'userlogin'               => 'Logge sïjse / skaepede nuhtjien',
'logout'                  => 'Logge olkese',
'userlogout'              => 'Logge ålkone',
'nologin'                 => "Lea dov ijje registreered? '''$1'''.",
'nologinlink'             => 'Skaepede nuhtjien',
'createaccount'           => 'Skaepede nuhtjien',
'gotaccount'              => "Åtna dov joe nuhtjiennomme? '''$1'''.",
'gotaccountlink'          => 'Logge sïjse',
'createaccountmail'       => 'meatan e-påaste',
'loginerror'              => 'Logge sïjse båajhtode',
'loginsuccesstitle'       => 'Dov lea daelie sïjse logge',
'loginsuccess'            => "'''Dov lea daelie sïjselogge nille {{SITENAME}} goh \"\$1\".'''",
'nosuchuser'              => 'Dïhte gååvnese ijje nuhtjien goh nomme "$1". Gïehtjedidh dov baakoehtidh, jallh skaepede orre nuhtjien.',
'nosuchusershort'         => 'Dïhte gååvnese ijje nuhtjien goh nomme "<nowiki>$1</nowiki>". Gïehtjedidh baakoehtidh.',
'nouserspecified'         => 'Dov galkedh tjaeledh nuhtjiennomme.',
'wrongpassword'           => 'Loevesbaakoe lea gåarhmede. Vuejnedh vihth.',
'wrongpasswordempty'      => 'Loevesbaakoe lea gåaroes. Vuejnedh vihth.',
'passwordtooshort'        => 'Dov loevesbaakoe lea ov-jiltighe jallh ihke åenehks. Dïhte galkedh åtna unnemes $1 vähta jih sjädta jeatjebe raejeste dov nuhtjiennomme.',
'mailmypassword'          => 'E-påaste loevesbaakoe',
'passwordremindertitle'   => 'Orre loevesbaakoe ihke {{SITENAME}}',
'noemail'                 => 'Dïhte lea ijje e-påaste tjaalesijjie registreeredh ihke nuhtjien "$1".',
'passwordsent'            => 'Orre loevesbaakoe åtna sjädta seedtie gåajkoe e-påaste tjaalesijjie
registreered ihke "$1".
Gïemhpes logge sïjse vihth männgan datne åtna låhka dïhte.',
'accountcreated'          => 'Nuhtjien skaepede',
'loginlanguagelabel'      => 'Gïele: $1',

# Password reset dialog
'oldpassword' => 'Båeries loevesbaakoe:',
'newpassword' => 'Orre loevesbaakoe:',
'retypenew'   => 'Odhasit orre loevesbaakoe:',

# Edit page toolbar
'bold_sample'     => 'Buajtehks tjaalege',
'bold_tip'        => 'Buajtehks tjaalege',
'italic_sample'   => 'Kursiive tjaalege',
'italic_tip'      => 'Kursiive tjaalege',
'link_sample'     => 'Lïenghke tiitele',
'link_tip'        => 'Sjisjnjie lïenghke',
'extlink_sample'  => 'http://www.example.com lïenghke tiitele',
'extlink_tip'     => 'Ehkstäärne lïenghke (måjhtajidh http:// prefihkse)',
'headline_sample' => 'Rubriike tjaalege',
'headline_tip'    => 'Daltese 2 rubriike',
'math_sample'     => 'Bïejedh fårmele daesnie',
'math_tip'        => 'Ryökneme fårmele (LaTeX)',
'nowiki_sample'   => 'Bïejedh ijje-hammode tjaalege daesnie',
'nowiki_tip'      => 'Rievdde wikïhammode',
'image_tip'       => 'Lååtje guvvie',
'media_tip'       => 'Meedia baalka lïenghke',
'sig_tip'         => 'Dov signatuvre meatan tïjjestäämpele',
'hr_tip'          => 'Horisontele sïeve (nuhtjie bïhteles-laakan)',

# Edit pages
'summary'                => 'Tjohkehtehteme:',
'subject'                => 'Ïebne/rubriike:',
'minoredit'              => 'Dïhte lea ohtje värrhtoedimmie',
'watchthis'              => 'Sïektjedh dïhte bielie',
'savearticle'            => 'Spååredh bielie',
'preview'                => 'Åvte-vuesiehtidh',
'showpreview'            => 'Vuesehte åvte-vuesiehtidh',
'showdiff'               => 'Vuesehte värrhtoedimmie',
'anoneditwarning'        => "'''Vaaroehtidh:''' Dov lea ijje logge sïjse. Dov IP tjaalesijjie båetedh spååredh sïjse dïhte bielie värrhtoedimmie histovrije.",
'summary-preview'        => 'Tjohkehtehteme åvte-vuesiehtidh:',
'loginreqlink'           => 'logge sïjse',
'loginreqpagetext'       => 'Dov galkedh $1 ihke vuesehte jeatjebh bielieh.',
'accmailtitle'           => 'Loevesbaakoe seedtie.',
'accmailtext'            => 'Loevesbaakoe ihke ”$1” utnedh seedtedh gåajkoe $2.',
'newarticle'             => '(Orre)',
'noarticletext'          => 'Dïhte lea daelie ijje tjaalege sïjse dïhte bielie, dov dorje [[Special:Search/{{PAGENAME}}|ohtsedh ihke dïhte bielie nomme]] sïjse jeatjebh bielieh jallh [{{fullurl:{{FULLPAGENAME}}|action=edit}} värrhtoedimmie dïhte bielie].',
'usercssyoucanpreview'   => "'''Tiipse:''' Nuhtjie 'Vuesehte åvte-vuesiehtidh' båaloe ihke pryövoe dov orre CSS åvte spååredh.",
'userjsyoucanpreview'    => "'''Tiipse:''' Nuhtjie 'Vuesehte åvte-vuesiehtidh' båaloe ihke pryövoe dov orre JS åvte spååredh.",
'updated'                => '(Orrestahteme)',
'note'                   => "'''Galtege:'''",
'previewnote'            => "'''Dïhte lea aktegh åvte-vuesiehtidh; värrhtoedimmieh ånta ijje sjïdtedh spååredh!'''",
'editing'                => 'Sjiehtedimmie $1',
'editingsection'         => 'Värrhtoedimmie $1 (sektiovne)',
'yourtext'               => 'Dov tjaalege',
'copyrightwarning'       => "Tjaeleste gaajhke värrhtoedimmieh gåajkoe {{SITENAME}} lea ahte gïehtjele goh maam buektedh nuelesne $2 (vuajna $1 ihke detaaljeh). Bïjre datne ijje sïjhtedh dov tjaalege galka värrhtoedimmieh jallh kåpieeres minngesne jeatjebh daerpies voete, galka datne ijje tjaala daesnie.<br />
Datne luhpede mijjieh aaj datne tjaala tjaalege jïjtje, jallh kåpieeret raejeste gaaltjie goh ijje vaarjele dejstie bäjjesereaktah, jallh plïerehke.<br />
'''LISSEHTE IJJE OLKESE BÄJJESEREAKTAHVAARJELE ÏEBNE NAMHTAH LUHPIE!'''",
'templatesused'          => '{{PLURAL:$1|Maal|Maler}}Maaleh nuhtjie nille dïhte bielie:',
'templatesusedpreview'   => '{{PLURAL:$1|Maal|Maaleh}} nuhtjie sïjse dïhte åvte-vuesiehtidh:',
'template-protected'     => '(vaarjeleme)',
'template-semiprotected' => '(lehkie-vaarjelidh)',
'nocreatetext'           => '{{SITENAME}} åtna gaertjiedidh nuepieh ahte skaepede orre bielieh.
Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge sïjse jallh skaepede nuhtjien]].',

# History pages
'viewpagelogs'        => 'Vuesehte loggeh ihke dïhte bielie',
'currentrev'          => 'Daaletje gïehtjedamme',
'revisionasof'        => 'Gïehtjedamme ihke $1',
'revision-info'       => 'Gïehtjedamme raejeste dïhte $1; $2',
'previousrevision'    => '←Båarasåabpoe gïehtjedamme',
'nextrevision'        => 'Minngebe gïehtjedamme→',
'currentrevisionlink' => 'Daaletje gïehtjedamme',
'cur'                 => 'daaletje',
'next'                => 'minngebe',
'last'                => 'minngemes',
'page_first'          => 'voestegh',
'page_last'           => 'minngemes',
'histfirst'           => 'Aareh',
'histlast'            => 'Minngemes',
'historysize'         => '({{PLURAL:$1|1 byte|$1 byteh}})',

# Revision feed
'history-feed-title'          => 'Gïehtjedamme histovrije',
'history-feed-item-nocomment' => '$1 dïhte $2',

# History merging
'mergehistory-from' => 'Gaaltjie bielie:',

# Diffs
'history-title'           => 'Gïehtjedamme histovrije ihke "$1"',
'difference'              => '(Joekehts gaskesne gïehtjedammeh)',
'lineno'                  => 'Sïeve $1:',
'compareselectedversions' => 'Mohtedidh veeljeme låhkoeh',
'editundo'                => 'ov-darjodh',
'diff-multi'              => '({{PLURAL:$1|Akte gaskese gïehtjedamme|$1 gaskese gïehtjedammeh}} vuesehte ijje.)',

# Search results
'searchresults'    => 'Ohtsedh resultaateh',
'searchresulttext' => 'Ihke jeenjebe bïevnesh bïjre ohtsedh {{SITENAME}}, vuejnedh [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'   => "Dov ohtsedh ihke '''[[:$1]]'''",
'prevn'            => 'övtebe {{PLURAL:$1|$1}}',
'nextn'            => 'minngeben {{PLURAL:$1|$1}}',
'viewprevnext'     => 'Vuesehth ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'   => 'Help:Sisvege',
'powersearch'      => 'Ohtsedh',

# Preferences page
'preferences'         => 'Sïjsestäälningeh',
'mypreferences'       => 'Mov sïjsesäälningeh',
'changepassword'      => 'Värrhtoedimmie loevesbaakoe',
'skin-preview'        => 'Åvte-vuesiehtidh',
'saveprefs'           => 'Spååredh',
'searchresultshead'   => 'Ohtsedh',
'timezonelegend'      => 'Tïjjedajve',
'localtime'           => 'Byjrehks tïjje',
'youremail'           => 'E-påaste:',
'username'            => 'Nuhtjiennomme:',
'uid'                 => 'Nuhtjien ID:',
'yourrealname'        => 'Ov nomme:',
'yourlanguage'        => 'Gïele:',
'yournick'            => 'Nuhjiennomme:',
'email'               => 'E-påaste',
'prefs-help-realname' => 'Ov nomme galkedh ijje tjaeledh. Bïjre datne veeljeme tjaeledh dov ov nomme, båetedh dïhte nuhtjie ihke tjaeledh dov barkoe.',

# User rights
'editinguser' => "Värrhtoedimmie nuhtjien '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",

# Groups
'group'       => 'Tjïerte:',
'group-bot'   => 'Jïjtjesvïhtjije',
'group-sysop' => 'Reeredh',

'group-bot-member'   => 'Jïjtjesvïhtjije',
'group-sysop-member' => 'Reerien',

'grouppage-sysop' => '{{ns:project}}:Reeredh',

# User rights log
'rightslog' => 'Nuhtjienreaktah logge',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|värrhtoedimmie|värrhtoedimmieh}}',
'recentchanges'                  => 'Männgan värrhtoedimmieh',
'recentchanges-feed-description' => 'Dåeriedidh männgan värrhtoedimmie sïjse wiki meatan dïhte feed.',
'rcnote'                         => "Vuelen vuesehte {{PLURAL:$1|dïhte männgan värrhtoedimmie|dah männgan '''$1''' värrhtoedimmieh}} nuelesne dah {{PLURAL:$2|männgan biejjie|männgan '''$2''' biejjieh}}, ihke $5, $4.",
'rcnotefrom'                     => "Vuelelen vuesehte dah männgan '''$1''' värrhtoedimmieh männgan '''$2'''.",
'rclistfrom'                     => 'Vuesehte orre värrhtoedimmieh aelkedh raejeste $1',
'rcshowhideminor'                => '$1 ohtje värrhtoedimmie',
'rcshowhidebots'                 => '$1 jïjtjesvïhtjijeh',
'rcshowhideliu'                  => '$1 värrhtoedimmie dejstie sïjselogge nuhtjienh',
'rcshowhideanons'                => '$1 anonyyme nuhtjienh',
'rcshowhidepatr'                 => '$1 dååhkasjehtedh värrhtoedimmieh',
'rcshowhidemine'                 => '$1 mov värrhtoedimmieh',
'rclinks'                        => 'Vuesehte männgan $1 värrhtoedimmieh nuelesne männgan $2 biejjieh<br />$3',
'diff'                           => 'joekehts',
'hist'                           => 'hist',
'hide'                           => 'Gaptjedh',
'show'                           => 'Vuesehte',
'minoreditletter'                => 'u',
'newpageletter'                  => 'O',
'boteditletter'                  => 'j',

# Recent changes linked
'recentchangeslinked'          => 'Värrhtoedimmieh nille krïense bielieh',
'recentchangeslinked-feed'     => 'Värrhtoedimmieh nille krïense bielieh',
'recentchangeslinked-toolbox'  => 'Värrhtoedimmieh nille krïense bielieh',
'recentchangeslinked-title'    => 'Värrhtoedimmie laktaseaddji gåajkoe "$1"',
'recentchangeslinked-noresult' => 'Ijje kïrense bielieh värrhtoedimmie nuelesne dïhte veeljeme tïjje-boelhke.',
'recentchangeslinked-summary'  => "Dïhte joekoelaakan bielie lästoe dah minngemes värrhtoedimmieh nille bielieh goh lea lïenghke. Bielieh [[Special:Watchlist|nille dov]] sïektjedhlästoe lea '''buajtehks'''.",

# Upload
'upload'         => 'Sadde guvvie',
'uploadbtn'      => 'Sadde baalka',
'uploadlogpage'  => 'Sadde logge',
'filename'       => 'Guvvienomme',
'filesource'     => 'Gaaltjie',
'savefile'       => 'Spååredh guvvie',
'uploadedimage'  => 'sadde "[[$1]]"',
'uploadvirus'    => 'Guvvie tjeekehdidh viirus! Bïevnesh: $1',
'sourcefilename' => 'Gaaltjie guvvienomme',

'upload-file-error' => 'Sjisjnjie båajhtode',

'license'        => 'Liseense',
'license-header' => 'Liseense',

# Special:ListFiles
'listfiles_search_for' => 'Ohtsedh ihke guvvie nomme:',
'imgfile'              => 'guvvie',
'listfiles'            => 'Guvvie lästoe',
'listfiles_name'       => 'Nomme',
'listfiles_user'       => 'Nuhtjien',
'listfiles_size'       => 'Stoerre',

# File description page
'file-anchor-link'          => 'Baalka',
'filehist'                  => 'Baalka histovrije',
'filehist-help'             => 'Diedtedh nille biejjie ihke vuajna man baalkan lij bealese dïhte tïjje.',
'filehist-current'          => 'daaletje',
'filehist-datetime'         => 'Biejjie/Tïjje',
'filehist-user'             => 'Nuhtjien',
'filehist-dimensions'       => 'Dimisjovneh',
'filehist-filesize'         => 'Guvvie stoerre',
'filehist-comment'          => 'Lahtestimmie',
'imagelinks'                => 'Lïenghkeh',
'linkstoimage'              => 'Tjuovvovasj {{PLURAL:$1|side|$1 sider}} bielieh lïenghkeh gåajkoe dïhte baalka:',
'nolinkstoimage'            => 'Dïhte lea ijje bielieh goh nuhtjie dïhte baalka.',
'sharedupload'              => 'Dïhte baalka lea $1 sadde goh juaka jih dorje sjädta nuhtjie dejstie jeatjebh prosjekte.',
'uploadnewversion-linktext' => 'Sadde orre låhkoe dejstie dïhte baalka',

# MIME search
'mimesearch' => 'MIME ohtsedh',
'mimetype'   => 'MIME vuekie:',

# List redirects
'listredirects' => 'Lästoe bïjre-dirisjovneh',

# Unused templates
'unusedtemplates'    => 'Ov-nuhtjie maaleh',
'unusedtemplateswlh' => 'jeatjebh lïenghkeh',

# Random page
'randompage' => 'Summal bielie',

# Random redirect
'randomredirect' => 'Summal odhasitstivren',

# Statistics
'statistics'              => 'Statistiike',
'statistics-header-users' => 'Nuhtjien statistiike',

'disambiguations' => 'Disambirgusjovne bielieh',

'doubleredirects' => 'Guektien-gïerth bïjre-dirisjovneh',

'brokenredirects'      => 'Earjohks bïrje-dirisjovneh',
'brokenredirects-edit' => '(värrhtoedimmie)',

'withoutinterwiki' => 'Bielieh namhtah gïele lïenghkeh',

'fewestrevisions' => 'Bielieh meatan dah unnebes gïehtjedamme',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|byte|byteh}}',
'ncategories'             => '$1 {{PLURAL:$1|kategorije|kategorijeh}}',
'nlinks'                  => '$1 {{PLURAL:$1|lïenghke|lïenghkeh}}',
'nmembers'                => '$1 {{PLURAL:$1|lihtsege|lihtsegh}}',
'nrevisions'              => '$1 {{PLURAL:$1|gïehtjedamme|gïehtjedammeh}}',
'nviews'                  => '$1 {{PLURAL:$1|vuesehte|vuesehteh}}',
'lonelypages'             => 'Eejhtegapth bielieh',
'uncategorizedpages'      => 'Ov-kategorije bielieh',
'uncategorizedcategories' => 'Ov-kategorije kategorijeh',
'uncategorizedimages'     => 'Ov-kategorije guvvieh',
'uncategorizedtemplates'  => 'Ov-kategorije maaleh',
'unusedcategories'        => 'Ov-nuhtjie kategorije',
'unusedimages'            => 'Ov-nnuhtjie guvvieh',
'wantedcategories'        => 'Vaajtelidh kategorijeh',
'wantedpages'             => 'Vaajtelidh bielieh',
'mostlinked'              => 'Jeenjebe lïenghkeh gåajkoe bielieh',
'mostlinkedcategories'    => 'Jeenjebe lïenghke gåajkoe kategorijeh',
'mostlinkedtemplates'     => 'Jeenjebe lïenghke gåajkoe malleh',
'mostcategories'          => 'Bielieh meatan jïjnje kategorijeh',
'mostimages'              => 'Jeenjebe lïenghke gåajkoe guvvieh',
'mostrevisions'           => 'Bielieh meatan jïjnje gïehtjedammeh',
'prefixindex'             => 'Prefiikse indeekse',
'shortpages'              => 'Åenehks bielieh',
'longpages'               => 'Guhkie bielieh',
'deadendpages'            => 'Tsuvvedh bielieh',
'protectedpages'          => 'Sïektjedh bielieh',
'listusers'               => 'Nuhtjien lästoe',
'newpages'                => 'Orre bielie',
'newpages-username'       => 'Nuhtjiennomme:',
'ancientpages'            => 'Båarasåabpoe bielieh',
'move'                    => 'Jåhta',
'movethispage'            => 'Jåhta dïhte bielie',

# Book sources
'booksources'               => 'Gärja gaaltjieh',
'booksources-search-legend' => 'Ohtsedh ihke gärja gaaltjieh',
'booksources-go'            => 'Vaadtsa',

# Special:Log
'specialloguserlabel'  => 'Nuhtjien:',
'speciallogtitlelabel' => 'Tiitele:',
'log'                  => 'Loggeh',
'all-logs-page'        => 'Gaajhke loggeh',

# Special:AllPages
'allpages'       => 'Gaajhke bielieh',
'alphaindexline' => '$1 ... $2',
'nextpage'       => 'Minngebe bielie ($1)',
'prevpage'       => 'Övtebe bielie ($1)',
'allpagesfrom'   => 'Vuesehte bielieh goh aelkedh meatan:',
'allarticles'    => 'Gaajhke bielieh',
'allpagesprev'   => 'Övtebe',
'allpagesnext'   => 'Minngebe',
'allpagessubmit' => 'Vaadtsa',
'allpagesprefix' => 'Vuesehte bielieh meatan prefihkse:',

# Special:Categories
'categories' => 'Karegorijeh',

# Special:ListUsers
'listusers-submit' => 'Vuesehte',

# E-mail user
'emailuser'       => 'E-påaste dïhte nuhtjien',
'emailpage'       => 'E-påaste nuhtjien',
'defemailsubject' => '{{SITENAME}} e-påaste',
'emailfrom'       => 'Raejeste',
'emailto'         => 'Gåajkoe',
'emailsubject'    => 'Ïebne',
'emailmessage'    => 'Dïjre',
'emailsend'       => 'Seedtie',
'emailsent'       => 'E-påaste seedtedh',

# Watchlist
'watchlist'         => 'Mov sïektjedhlästoe',
'mywatchlist'       => 'Mov sïektjedhlästoe',
'addedwatch'        => 'Lissiehtidh gåajkoe sïektjedhlästoe',
'removedwatch'      => 'Sihkojuvvon raejeste sïektjedhlästoe',
'removedwatchtext'  => 'Bielie "[[:$1]]" lea sihkojuvvon raejeste [[Special:Watchlist|dov sïektjedhlästoe]].',
'watch'             => 'Sïektjedh',
'watchthispage'     => 'Sïektjedh dïhte bielie',
'unwatch'           => 'Ov-sïektjedh',
'watchlist-details' => '{{PLURAL:$1|$1 bielie|$1 bielieh}} sïektjedh (doekoe dïerhkestidhbielieh).',
'wlshowlast'        => 'Vuesehte minngemes $1 täjmoeh $2 biejjieh $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Sïektjeminie...',
'unwatching' => 'Ov-sïektjedh...',

'enotif_newpagetext'           => 'Dïhte lea orre bielie.',
'enotif_impersonal_salutation' => '{{SITENAME}} nuhtjien',
'created'                      => 'skaepede',

# Delete
'deletepage'            => 'Tjåegkedh bielie',
'historywarning'        => 'Vaaroehtidh: Bielie datne gïehtele ahte sihkut åtna histovrije:',
'actioncomplete'        => 'Deahpadimmie voerkes',
'deletedtext'           => '"<nowiki>$1</nowiki>" lea sihkojuvvon.
Vuajna $2 ihke galtege bïjre männgan sihkojuvvonh.',
'deletedarticle'        => 'sihkoj "[[$1]]"',
'dellogpage'            => 'Sihkkun logge',
'deletecomment'         => 'Gaavhtan ihke sihkkuma',
'deleteotherreason'     => 'Jeatjebh/ehkstre gaavhtan:',
'deletereasonotherlist' => 'Jeatjebh gaavhtan',

# Rollback
'rollbacklink' => 'jurrelde bååstede',

# Protect
'protectlogpage'              => 'Vaarjelidh logge',
'prot_1movedto2'              => '[[$1]] jåhta gåajkoe [[$2]]',
'protect-legend'              => 'Skylledh vaarjelidh',
'protectcomment'              => 'Lahtestimmie:',
'protectexpiry'               => 'Boarasnuvve:',
'protect_expiry_invalid'      => 'Ov-jiltiige buaorasjnuvvenaigi.',
'protect_expiry_old'          => 'Boarasnuvvenaigi lea vaesedh.',
'protect-text'                => "Daesnie dorje datne vuajna jih värrhtoedimmie vaarjelidhdaltese dejstie bielie '''<nowiki>$1</nowiki>'''.",
'protect-locked-access'       => "Dov nuhtjien åtna ijje luhpie gåajkoe värrhtoedimmie tjaeleste-vaarjelidh.
Daaletje tjaeleste-vaarjelidh sïjsestäälninge ihke bielie '''$1''' lea:",
'protect-default'             => '(åvte-veeljeme)',
'protect-fallback'            => 'Luhpie "$1"',
'protect-level-autoconfirmed' => 'Tjöödtjehtidh ov-registreered nuhtjienh',
'protect-level-sysop'         => 'Barre reeredh',
'protect-summary-cascade'     => 'viididuvvon',
'protect-expiring'            => 'boarasnuvve $1 (UTC)',
'protect-cascade'             => 'Vaarjelidh bielieh guosket sïjse dïhte bielie (viidit suodjaluse)',
'protect-cantedit'            => 'Datne dorje ijje värrhtoedimmie vaarjelidhdaltese ihke dïhte bielie, ihke datne ijja åtna luhpie ahte värrhtoedimmie dïhte.',
'protect-expiry-options'      => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite',
'restriction-type'            => 'Permisjovne:',
'restriction-level'           => 'Restriksjovne daltese:',

# Restrictions (nouns)
'restriction-edit'   => 'Värrhtoedimmie',
'restriction-move'   => 'Jåhta',
'restriction-create' => 'Skaepiedidh',

# Restriction levels
'restriction-level-sysop' => 'dïeves-vaarjelidh',

# Undelete
'undeleterevisions'      => '$1 {{PLURAL:$1|gïehtjedamme|gïehtjedammeh}} våarhkoe',
'undeletebtn'            => 'Mahtsat',
'undelete-search-submit' => 'Ohtsedh',

# Namespace form on various pages
'namespace'      => 'Nommeïebne:',
'invert'         => 'Jarkoe veeljeme',
'blanknamespace' => '(Bielieh)',

# Contributions
'contributions' => 'Nuhtjien värrhtoedimmieh',
'mycontris'     => 'Mov värrhtoedimmieh',
'contribsub2'   => 'Ihke $1 ($2)',
'uctop'         => '(gïerege)',
'month'         => 'Raejeste aske (jih övtebe):',
'year'          => 'Raejeste jaepie (jih övtebe):',

'sp-contributions-newbies-sub' => 'Ihke orre nuhtjienh',
'sp-contributions-blocklog'    => 'Tjöödtjehtidh logge',
'sp-contributions-talk'        => 'Digkiedimmie',
'sp-contributions-username'    => 'IP Tjaalesijjie jallh nuhtjiennomme:',
'sp-contributions-submit'      => 'Ohtsedh',

# What links here
'whatlinkshere'       => 'Bilieh goh lïenghkeh diekie',
'whatlinkshere-title' => 'Bielieh goh lïenghke gåajkoe $1',
'whatlinkshere-page'  => 'Bielie:',
'linkshere'           => "Tjuovvovasj bielie lïenghke gåajkoe '''[[:$1]]''':",
'nolinkshere'         => "Ijje bielieh lïenghke gåajkoe '''[[:$1]]'''.",
'isredirect'          => 'bïjre-dirisjovne bielie',
'istemplate'          => 'lasihuvvon goh maale',
'whatlinkshere-prev'  => '{{PLURAL:$1|övtebe|övtebe $1}}',
'whatlinkshere-next'  => '{{PLURAL:$1|minngebe|minngebe $1}}',
'whatlinkshere-links' => '← lïenghkeh',

# Block/unblock
'blockip'              => 'Tjöödtjehtidh nuhtjien',
'ipaddress'            => 'IP Tjaalesijjie:',
'ipadressorusername'   => 'IP Tjaalesijjie jallh nuhtjiennomme:',
'ipbother'             => 'Jeatjebh tïjje:',
'ipboptions'           => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite',
'ipbotheroption'       => 'jeatjebh',
'ipblocklist'          => 'Lästoe bijjelen tjöödtjehtidh IP tjaalesijjieh jih nuhtjiennommeh',
'ipblocklist-username' => 'Nuhtjiennomme jallh IP tjaalesijjie:',
'ipblocklist-submit'   => 'Ohtsedh',
'blocklink'            => 'tjöödtjehtidh',
'unblocklink'          => 'ov-tjöödtjehtidh',
'contribslink'         => 'dåarjoeh',
'blocklogpage'         => 'Tjöödtjehtidh logge',
'blocklogentry'        => 'blåhkedidh "[[$1]]" $2 $3',

# Developer tools
'lockdb'            => 'Tjuevtedh daatabaase',
'lockbtn'           => 'Tjuevtedh daatabaase',
'databasenotlocked' => 'Daatabaase lea ijje tjuevtedh.',

# Move page
'move-page-legend' => 'Jåhta bielie',
'movearticle'      => 'Jåhta bielie:',
'newtitle'         => 'Gåajkoe orre tiitele:',
'move-watch'       => 'Sïektjedh dïhte bielie',
'movepagebtn'      => 'Jåhta bielie',
'pagemovedsub'     => 'Jåhta lähkoe',
'articleexists'    => 'Bielie meatan dïhte nomme gååvnese joe, jallh
nome dov åtna veeljeme lea ijje jiiltige.
Gïemhpes veeljeme jeatjebh nomme.',
'movedto'          => 'jåhta gåajkoe',
'movetalk'         => 'Jåhta aaj dïerkestidhbielie, bïjre dïhte gååvnese.',
'1movedto2'        => '[[$1]] jåhta gåajkoe [[$2]]',
'movelogpage'      => 'Jåhta logge',
'movereason'       => 'Gaavhtan:',
'revertmove'       => 'jåhta bååstede',

# Export
'export'           => 'Ehksporte bielieh',
'export-submit'    => 'Ehksporte',
'export-addcat'    => 'Lissiehtidh',
'export-templates' => 'Inkludera mallar',

# Namespace 8 related
'allmessages'     => 'Systeeme dïrje',
'allmessagesname' => 'Nomme',

# Thumbnails
'thumbnail-more'  => 'Vijriedidh',
'thumbnail_error' => 'Båajhtode nuelesne skaepede dejstie miniatyvreguvvie: $1',

# Special:Import
'import'                  => 'Imporhte bielieh',
'import-interwiki-submit' => 'Imporhte',
'importstart'             => 'Imporhte bielieh...',
'import-revision-count'   => '$1 {{PLURAL:$1|gïehtjedamme|gïehtjedammeh}}',
'importfailed'            => 'Imporhte steegkeldahkesne: $1',
'importsuccess'           => 'Imporhte lähkoe!',

# Import log
'importlogpage'                    => 'Imporhte logge',
'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|gïehtjedamme|gïehtjedammeh}}',
'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|gïehtjedamme|gïehtjedammeh}} raejeste $2',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Mov nuhtjienbielie',
'tooltip-pt-mytalk'               => 'Mov dïjveldidh bielie',
'tooltip-pt-preferences'          => 'Mov sïjsesäälningeh',
'tooltip-pt-watchlist'            => 'Lästoe bijjelen bielieh goh sïektjedh',
'tooltip-pt-mycontris'            => 'Lästoe bijjelen mov värrhtoedimmie',
'tooltip-pt-login'                => 'Dov åådtje logge sïjse, bine dïhte lea ijje daerpies.',
'tooltip-pt-logout'               => 'Logge ålkone',
'tooltip-ca-talk'                 => 'Dïjveldidh bïjre sisvege bieliej',
'tooltip-ca-edit'                 => 'Dov dorje värrhtoedimmie dïhte bielie. Nuhtjie åvte-vuesiehtidh båaloe åvte spååredh.',
'tooltip-ca-addsection'           => 'Lissiehtidh lahtestimmie gåajkoe dïhte dïjveldidh.',
'tooltip-ca-viewsource'           => 'Dïhte bielie lea vaarjelidh. Dov dorje vuesehte gaaltjiej.',
'tooltip-ca-protect'              => 'Vaarjelidh dïhte bielie',
'tooltip-ca-delete'               => 'Tjåegkedh dïhte bielie',
'tooltip-ca-move'                 => 'Jåhta dïhte bielie',
'tooltip-ca-watch'                => 'Lissiehtidh dïhte bielie gåajkoe dov sïektjedhlästoe',
'tooltip-ca-unwatch'              => 'Sirdde dïhte bielie raejeste dov sïektjedhlästoe',
'tooltip-search'                  => 'Ohtsedh {{SITENAME}}sne',
'tooltip-p-logo'                  => 'Åejjiebielie',
'tooltip-n-mainpage'              => 'Gåajkoe aalkoebielie vaadtsa',
'tooltip-n-portal'                => 'Bïjre prosjekte, mij dov dorje, lij dov gaavnedh daeverh',
'tooltip-n-currentevents'         => 'Bïevnesh bïjre daaletje deahpadimmieh',
'tooltip-n-recentchanges'         => 'Lästoe männganes sjiehtedh bijjelen nille {{SITENAME}}.',
'tooltip-n-randompage'            => 'Vaadtsa summal bielie',
'tooltip-n-help'                  => 'Viehkie jih bïevnesh {{SITENAME}} bïjre.',
'tooltip-t-whatlinkshere'         => 'Lästoe bijjelen gaajhke wiki bielieh goh lïenghke diekie',
'tooltip-feed-rss'                => 'RSS feed ihke dïhte bielie',
'tooltip-feed-atom'               => 'Atom feed ihke dïhte bielie',
'tooltip-t-contributions'         => 'Vuesehte lästoe bijjelen värrhtoedimmieh dejstie dïhte nuhtjien',
'tooltip-t-emailuser'             => 'Seedtedh e-påaste gåajkoe dïhte nuhtjien',
'tooltip-t-upload'                => 'Sadde guvvir jallh meedia baalkah',
'tooltip-t-specialpages'          => 'Lästoe gaajhke joekoen bielieh bijjelen',
'tooltip-ca-nstab-user'           => 'Vuesehte nuhtjien bieliej',
'tooltip-ca-nstab-project'        => 'Vuesehte prosjekte bieliej',
'tooltip-ca-nstab-image'          => 'Vuesehte guvvie bieliej',
'tooltip-ca-nstab-template'       => 'Vuesehte maalej',
'tooltip-ca-nstab-help'           => 'Vuesehte viehkie bieliej',
'tooltip-ca-nstab-category'       => 'Vuesehte kategorije bieliej',
'tooltip-minoredit'               => 'Mïerhkesjidh dïhte lea ohtje värrhtoedimmie',
'tooltip-save'                    => 'Spååredh dov värrhtoedimmieh',
'tooltip-preview'                 => 'Åvte-vuesiehtidh dov värrhtoedimmie, gïemhpes nuhtjie dïhte åvte spååredh!',
'tooltip-diff'                    => 'Vuesehte guhte värrhtoedimmieh dov åtna dorjeme dejstie tjaalege.',
'tooltip-compareselectedversions' => 'Vuesehte joekehts gaskesne dah göökte vïhtesjidh låhkoeh dejstie dïhte bielie.',
'tooltip-watch'                   => 'Lissiehtidh dïhte bielie gåajkoe dov sïektjedhlästoe',

# Attribution
'siteuser'  => '{{SITENAME}} nuhtjien $1',
'siteusers' => '{{SITENAME}} nuhtjien(h) $1',

# Info page
'infosubtitle' => 'Bïevnesh ihke bielie',
'numedits'     => 'Låhkoe värrhtoedimmieh (bielie): $1',
'numtalkedits' => 'Låhkoe värrhtoedimmieh (dïjvaldidh bielie): $1',

# Math errors
'math_unknown_error' => 'ammes båajhtede',

# Patrol log
'patrol-log-auto' => '(jïjtsistie)',

# Browsing diffs
'previousdiff' => '← Övtebe joekehts',
'nextdiff'     => 'Minngebe joekehts →',

# Media information
'file-info'            => 'baalka stoerre: $1, MIME-vuekie: $2',
'file-info-size'       => '$1 × $2 pixel, baalka stoerre: $3, MIME-vuekie: $4',
'file-nohires'         => '<small>Ijje jïlle bäjjeselöösninge jaksoes.</small>',
'svg-long-desc'        => 'SVG baalka, maadth-stoerre $1 × $2 pixel, baalka stoerre: $3',
'show-big-image'       => 'Dïeves stoerre',
'show-big-image-thumb' => '<small>Stoerre ihke dïhte vuesiehtidh: $1 × $2 pixel</small>',

# Special:NewFiles
'newimages' => 'Gallerije dejstie orre baalkah',
'ilsubmit'  => 'Ohtsedh',

# Metadata
'metadata'          => 'Metadaata',
'metadata-expand'   => 'Vuesehte vijriedidh detaaljeh',
'metadata-collapse' => 'Gaptjedh vijrede daeverh',
'metadata-fields'   => 'EXIF-dajve goh lästoe sïjse dïhte dïrje vuesehte nille guvviebielie gåessie metadaatataabelle lea unniedidh.
Jeatjebh dajveh lea gaptjedh goh sïejhme, bine vuesehte gåessie taabelle stoerre.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength',

# EXIF tags
'exif-imagewidth'         => 'Gamte',
'exif-imagelength'        => 'Gåhkoe',
'exif-model'              => 'Guvviedahke hammohke',
'exif-software'           => 'Möövhkesvaare nuhtjie',
'exif-filesource'         => 'Guvvie gaaltjie',
'exif-gpslatituderef'     => 'Noerhte jallh Åarjetje Laatituude',
'exif-gpslatitude'        => 'Laatituude',
'exif-gpslongituderef'    => 'Lulnie jallh Jillege Låångdituude',
'exif-gpslongitude'       => 'Låångdituude',
'exif-gpsareainformation' => 'Nomme ihke GPS davje',

'exif-meteringmode-0'   => 'Ammes',
'exif-meteringmode-255' => 'Jeatjebh',

'exif-lightsource-0' => 'Ammes',

'exif-scenecapturetype-0' => 'Sïejhme',

'exif-contrast-1' => 'Möövhkes',
'exif-contrast-2' => 'Garre',

'exif-sharpness-1' => 'Möövhkes',
'exif-sharpness-2' => 'Garre',

'exif-subjectdistancerange-0' => 'Ammes',

# Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
'exif-gpslatitude-n' => 'Noerhte latituude',
'exif-gpslatitude-s' => 'Åarjetje laatituude',

# Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
'exif-gpslongitude-e' => 'Lulnie låångdituude',
'exif-gpslongitude-w' => 'Jillege låångdituude',

# External editor support
'edit-externally'      => 'Värrhtoedimmie dïhte baalka meatan ehksteerne applikasjovne',
'edit-externally-help' => 'Vuajna [http://www.mediawiki.org/wiki/Manual:External_editors instalasjovne instruksjovne] ihke vielie bïevnesh.',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'gaajhke',
'imagelistall'     => 'gaajhke',
'watchlistall2'    => 'gaajhke',
'namespacesall'    => 'gaajhke',
'monthsall'        => 'gaajhke',

# Scary transclusion
'scarytranscludetoolong' => '[URL lea ihke guhkie; gaatelassjedh]',

# action=purge
'confirm-purge-top' => 'Döömedh cache ihke dïhte bielie?',

# Multipage image navigation
'imgmultipageprev' => '← övtebe bielie',
'imgmultipagenext' => 'minngebe bielie →',
'imgmultigo'       => 'Vaadtsa!',

# Table pager
'table_pager_next'         => 'Minngebe bielie',
'table_pager_prev'         => 'Övtebe bielie',
'table_pager_first'        => 'Voestemes bielie',
'table_pager_last'         => 'Minngemes bielie',
'table_pager_limit_submit' => 'Vaadtsa',

# Auto-summaries
'autosumm-new' => 'Orre bielie: $1',

# Live preview
'livepreview-loading' => 'Leedtedh…',
'livepreview-ready'   => 'Leedtedh… Voerkes!',

# Watchlist editing tools
'watchlisttools-view' => 'Sïektjedhlästoe',
'watchlisttools-edit' => 'Vuesehte jih värrhtoedimmie sïektjedhlästoe',
'watchlisttools-raw'  => 'Värrhtordimmie saajpe sïektjedhlästoe',

# Core parser functions
'unknown_extension_tag' => 'Ammes ekshtensjovne lissie "$1"',

# Special:Version
'version' => 'Låhkoe',

# Special:SpecialPages
'specialpages' => 'Joekoen bielieh',

);
